@@ -142,12 +142,29 @@ struct PropertyView: PROPERTYVIEW_BASE_ACCESS WidgetTraits<T>::PropertyType
             return static_cast<WidgetType *>(IUFindOnSwitch(this));
         }
 
+        template <typename X = T, enable_if_is_same_t<X, ISwitch> = true>
+        bool isSwitchOn(const std::string &name) const
+        {
+            auto onSwitch = findOnSwitch();
+            return (onSwitch && onSwitch->isNameMatch(name));
+        }
+
         template <typename X = T, enable_if_is_same_t<X, ISwitch> = true>
         int findOnSwitchIndex() const
         {
             return IUFindOnSwitchIndex(this);
         }
 
+        template <typename X = T, enable_if_is_same_t<X, ISwitch> = true>
+        std::string findOnSwitchName() const
+        {
+            auto onSwitch = findOnSwitch();
+            if (onSwitch)
+                return onSwitch->getName();
+            else
+                return std::string();
+        }
+
     public: // only for INumber
         template <typename X = T, enable_if_is_same_t<X, INumber> = true>
         void updateMinMax();                                   /* outside implementation - only driver side, see indipropertyview_driver.cpp */
@@ -233,6 +250,7 @@ struct PropertyView: PROPERTYVIEW_BASE_ACCESS WidgetTraits<T>::PropertyType
     public: // only driver side
         bool load();
         void save(FILE *f) const;                              /* outside implementation */
+        bool snoop(XMLEle *root);                              /* outside implementation */
 
         void vapply(const char *format, va_list args)
         const;   /* outside implementation - only driver side, see indipropertyview_driver.cpp */
@@ -308,6 +326,15 @@ struct PropertyView: PROPERTYVIEW_BASE_ACCESS WidgetTraits<T>::PropertyType
             const char * const names[], int n
         ); /* outside implementation - only driver side, see indipropertyview_driver.cpp */
 
+        template <typename X = T, enable_if_is_same_t<X, IText> = true>
+        bool isUpdated(const char * const texts[], const char * const names[], int n) const;
+
+        template <typename X = T, enable_if_is_same_t<X, INumber> = true>
+        bool isUpdated(const double values[], const char * const names[], int n) const;
+
+        template <typename X = T, enable_if_is_same_t<X, ISwitch> = true>
+        bool isUpdated(const ISState states[], const char * const names[], int n) const;
+
 
     public:
         WidgetType *begin() const
@@ -361,7 +388,10 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
         WidgetView(const WidgetView<Type> &other): Type(other)
         {
             this->text = nullptr;
-            setText(other.text);
+            if (other.text != nullptr)
+            {
+                setText(other.text);
+            }
         }
         WidgetView(WidgetView<Type> &&other): Type(other)
         {
@@ -472,7 +502,7 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
         {
             return getLabel() == otherLabel;
         }
-        
+
         bool isEmpty() const
         {
             return getText()[0] == '\0';
@@ -1225,6 +1255,36 @@ inline void PropertyView<IBLOB>::save(FILE *f) const
     IUSaveConfigBLOB(f, this);
 }
 
+template <>
+inline bool PropertyView<INumber>::snoop(XMLEle *root)
+{
+    return IUSnoopNumber(root, this) == 0;
+}
+
+template <>
+inline bool PropertyView<IText>::snoop(XMLEle *root)
+{
+    return IUSnoopText(root, this) == 0;
+}
+
+template <>
+inline bool PropertyView<ISwitch>::snoop(XMLEle *root)
+{
+    return IUSnoopSwitch(root, this) == 0;
+}
+
+template <>
+inline bool PropertyView<ILight>::snoop(XMLEle *root)
+{
+    return IUSnoopLight(root, this) == 0;
+}
+
+template <>
+inline bool PropertyView<IBLOB>::snoop(XMLEle *root)
+{
+    return IUSnoopBLOB(root, this) == 0;
+}
+
 template <typename T>
 inline void PropertyView<T>::setTimeout(double timeout)
 {
